@@ -25,11 +25,7 @@ class SubscriptionsApi(BaseApi):
         address. The subscription starts immediately, unless the request
         includes 
         the optional `start_date`. Each individual subscription is associated
-        with a particular location. 
-        For more information, 
-        see [Subscription API
-        Overview](https://developer.squareup.com/docs/docs/subscriptions-api/ov
-        erview).
+        with a particular location.
 
         Args:
             body (CreateSubscriptionRequest): An object containing the fields
@@ -188,10 +184,7 @@ class SubscriptionsApi(BaseApi):
         """Does a PUT request to /v2/subscriptions/{subscription_id}.
 
         Updates a subscription. You can set, modify, and clear the 
-        `subscription` field values. For more information and examples, see 
-        [Update
-        subscriptions](https://developer.squareup.com/docs/docs/subscriptions-a
-        pi/overview#update-subscriptions).
+        `subscription` field values.
 
         Args:
             subscription_id (string): The ID for the subscription to update.
@@ -242,12 +235,9 @@ class SubscriptionsApi(BaseApi):
                             subscription_id):
         """Does a POST request to /v2/subscriptions/{subscription_id}/cancel.
 
-        Cancels a subscription immediately and sets the subscription
-        `status` to `CANCELED`. You can also use the `UpdateSubscription`
-        endpoint to cancel a subscription at a future date. For more
-        information, see
-        [CancelSubscriptions](https://developer.squareup.com/docs/docs/subscrip
-        tions-api/overview#cancel-subscriptions).
+        Sets the `canceled_date` field to the end of the active billing
+        period.
+        After this date, the status changes from ACTIVE to CANCELED.
 
         Args:
             subscription_id (string): The ID of the subscription to cancel.
